*************************************************
* Linear and Logistic Regression
* Ph. D course , Aarhus University
* copyright: Morten Frydenberg
*            Department of Biostatistics
*
*  Most of the STATA code used at 
*                DAY 4 
*************************************************
cd "E:\KURSER\PostReg\Version6\Lectures\Day4
capture log close
log using RegDay4.log,replace
*******************************************************
* Plotting the relationship between logit and probability
* PLOT01
*******************************************************
twoway                                          ///
( function y=exp(x)/(1+exp(x) ),range(-5 5) clco(black))     ///
, xlabel( -5(1)5)    xtitle( "logit=ln(odds)")   ///
  ylabel( 0(.1)1)    ytitle( "Probability") 
 graph export Regday4_01.wmf, replace
*******************************************************
* Obsesity and sex
*******************************************************

use obese,clear
sort age
tabu obese sex,col
* prior to version 11
*char sex[omit]1
*xi: logit obese i.sex
*xi: logit obese i.sex,or
logit obese b1.sex,baselevel
logit obese b1.sex,baselevel or cformat(%6.4f)


*******************************************************
* Obsesity and age
*******************************************************
generate age45=age-45
logit obese age45
logit obese age45,or cformat(%6.4f)
lincom age45*4.5 ,or cformat(%6.4f)
*******************************************************
* Obsesity and age plot of fitted
* PLOT02 and PLOT03
*******************************************************
regeq


twoway (function y= $b0+$b1*(x-45) ,range(age)lw(thick) ) ///
 , ytitle("log odds")xlabel(30(5)70) xline(45) xtitle( "Age in years")
  graph export Regday4_02.wmf, replace
  
twoway (function y= invlogit($b0+$b1*(x-45)  ) ,range(age)lw(thick) ) ///
 , ytitle("prevalence")xlabel(30(5)70) xline(45) xtitle( "Age in years")
  graph export Regday4_03.wmf, replace
  
* if you have a lot of data like here
predict fit1 if e(sample),xb
predict p1 if e(sample),p
line fit1 age ,clco(black) clw(thick) ytitle("log odds")xlabel(30(5)70) xline(45)
  graph export Regday4_02b.wmf, replace
line p1 age ,clco(black) clw(thick) ytitle("prevalence")xlabel(30(5)70) xline(45)
  graph export Regday4_03b.wmf, replace

*******************************************************
* Obsesity and age in groups
*******************************************************
egen  agegrp7=cut(age), at(0,35,40,45,50,55,60,120) label
table agegrp7 ,c(min age max age count obese sum obese)row
logit obese i.agegrp7,baselevel	
logit obese i.agegrp7,baselevel	or cformat(%6.4f)
testparm i.agegrp7
logit obese b3.agegrp7,baseleve or cformat(%6.4f)

*******************************************************
* Obesity and age in groups plot of fitted
* PLOT04
*******************************************************

predict fit2 if e(sample),xb
predict p2 if e(sample),p
line fit2 age ,clco(black) connect(J)  clpa(1) clw(thick) ///
   , ytitle("log odds")xlabel(30(5)70) name(p1, replace)
line p2 age ,clco(black) connect(J)  clpa(1) clw(thick) ///
  , ytitle("prevalence") xlabel(30(5)70) name(p2, replace) 
graph combine  p1 p2
graph export Regday4_04.wmf, replace
*******************************************************
* Obsesity and age comparing the two modes
* PLOT05
*******************************************************

twoway ///
 (line fit1 age ,clco(black) clw(thick) clpa(1) ) ///
 (line fit2 age ,clco(blue) connect(J)  clw(thick) clpa(dash)) ///
 , ytitle("log odds")xlabel(30(5)70) name(p1, replace) ///
 legend(ring(0) pos(11) label(1 "model1" )label(2 "model2") ) 
twoway ///
 (line p1 age ,clco(black) clpa(1) clw(thick)) ///
 (line p2 age ,clco(blue) connect(J) clw(thick) clpa(dash)) ///
 , ytitle("prevalence") xlabel(30(5)70) name(p2, replace) ///
 legend(ring(0) pos(11) label(1 "model1" )label(2 "model2") ) 
graph combine  p1 p2
graph export Regday4_05.wmf, replace

*******************************************************
* Obsesity and sex and age no interaction
*******************************************************
logit obese b1.sex age45,
logit,or baselevel cformat(%6.4f)

*******************************************************
* PLOT06
*******************************************************

predict fit3 if e(sample),xb
predict p3 if e(sample),p
twoway ///
  (line fit3 age if sex==1 & e(sample) ,clco(blue) clpa(1)    clw(thick) ) ///
  (line fit3 age if sex==2 & e(sample) ,clco(red)  clpa(dash) clw(thick) ) ///
  , ytitle("log odds")xlabel(30(5)70) name(p1, replace)xline(45) ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women") ) 
twoway ///
 (line p3 age if sex==1 & e(sample) ,clco(blue) clpa(1)    clw(thick) ) ///
 (line p3 age if sex==2 & e(sample) ,clco(red)  clpa(dash) clw(thick) ) ///
 , ytitle("prevalence")xlabel(30(5)70) name(p2, replace) xline(45) ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women") ) 
graph combine  p1 p2
graph export Regday4_06.wmf, replace


*******************************************************
* Obsesity and sex and age with interaction
*******************************************************
logit obese b1.sex##c.age45
logit,or baselevel cformat(%6.4f)
 
*******************************************************
* PLOT07
*******************************************************
regeq

twoway ///
(function y=$b0+$b1 *0 + $b2 * (x-45) + $b3 * 0*(x-45)  ,  ///
      range(age)clco(blue) clpa(1)    clw(thick) ) ///
(function y=$b0+$b1 *1 + $b2 * (x-45) + $b3 * 1*(x-45)  ,  ///
      range(age)clco(red)  clpa(dash) clw(thick) ) ///
 , ytitle("log odds")xlabel(30(5)70) xline(45) name(p1,replace) ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women")) 
twoway ///
(function y=invlogit($b0+$b1 *0 + $b2 * (x-45) + $b3 * 0*(x-45) ) ,  ///
      range(age)clco(blue) clpa(1)    clw(thick) ) ///
(function y=invlogit($b0+$b1 *1 + $b2 * (x-45) + $b3 * 1*(x-45)  ),  ///
      range(age)clco(red)  clpa(dash) clw(thick) ) ///
   , ytitle("prevalence")xlabel(30(5)70) xline(45)name(p2, replace)  ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women")) 
graph combine  p1 p2
graph export Regday4_07.wmf, replace

* ploting by fitted
predict fit4 if e(sample),xb
predict p4 if e(sample)
twoway ///
  (line fit4 age if sex==1 & e(sample) ,clco(blue) clpa(1)    clw(thick) ) ///
  (line fit4 age if sex==2 & e(sample) ,clco(red)  clpa(dash) clw(thick) ) ///
  , ytitle("log odds")xlabel(30(5)70) xline(45) name(p1,replace) ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women")) 
twoway ///
  (line p4 age if sex==1 & e(sample) ,clco(blue) clpa(1)    clw(thick) ) ///
  (line p4 age if sex==2 & e(sample) ,clco(red)  clpa(dash) clw(thick) ) ///
  , ytitle("prevalence")xlabel(30(5)70) xline(45)name(p2, replace)  ///
 legend(ring(0) pos(11) label(1 "men" )label(2 "women")) 
graph combine  p1 p2
graph export Regday4_07.wmf, replace


***********************************************
* cancer data
*********************************************** 
use case_control,clear
tabodds cancer age
tabodds cancer age, or
tabodds cancer age, or base(3)

logit cancer b0.smoker b1.age,or baselev
logit cancer b0.smoker b3.age,or baselev
estimates store model1
logit cancer b0.smoker
estimates store model2
lrtest model1 model2
***********************************************
log close


